Handler

Struct Handler 

pub struct Handler<Client> { /* private fields */ }

Implementations

Source

impl<Client> Handler<Client>

pub fn new<H, Args>(handler_fn: H) -> Self
where H: HandlerFn<Args>, Args: Extractor<Client> + Send, Args::Error: Send, Client: Send + Sync + 'static,

pub fn new_service<S, Args>(service: S) -> Self
where S: Service<Args> + Clone + Send + Sync + 'static, S::Response: Into<EventReturn>, S::Error: Into<Error> + Send, S::Future: Send, Args: Extractor<Client> + Send, Args::Error: Send, Client: Send + Sync + 'static,

pub fn filter(self, val: impl Filter<Client>) -> Self
where Client: Send + Sync + 'static,

Source

impl<Client> Handler<Client>
where Client: Send + Sync,

pub async fn check( &mut self, request: Request<Client>, ) -> Result<(bool, Request<Client>), (EventErrorKind, Request<Client>)>

Check if the handler pass the filters. If the handler pass all them, it will be called.

Errors

If any filter returns error, it will be wrapped into FilterError and returned together with the request