pub struct EncryptedCredentials {
pub data: Box<str>,
pub hash: Box<str>,
pub secret: Box<str>,
}Expand description
Describes data required for decrypting and authenticating crate::types::EncryptedPassportElement. See the Telegram Passport Documentation for a complete description of the data decryption and authentication processes.
Documentation
Fields
data: Box<str>Base64-encoded encrypted JSON-serialized data with unique user’s payload, data hashes and secrets required for crate::types::EncryptedPassportElement decryption and authentication
hash: Box<str>Base64-encoded data hash for data authentication
secret: Box<str>Base64-encoded secret, encrypted with the bot’s public RSA key, required for data decryption
Implementations
Sourceimpl EncryptedCredentials
impl EncryptedCredentials
Sourcepub fn new<T0: Into<Box<str>>, T1: Into<Box<str>>, T2: Into<Box<str>>>(
data: T0,
hash: T1,
secret: T2,
) -> Self
pub fn new<T0: Into<Box<str>>, T1: Into<Box<str>>, T2: Into<Box<str>>>( data: T0, hash: T1, secret: T2, ) -> Self
Creates a new EncryptedCredentials.
Arguments
data- Base64-encoded encrypted JSON-serialized data with unique user’s payload, data hashes and secrets required forcrate::types::EncryptedPassportElementdecryption and authenticationhash- Base64-encoded data hash for data authenticationsecret- Base64-encoded secret, encrypted with the bot’s public RSA key, required for data decryption
Sourcepub fn data<T: Into<Box<str>>>(self, val: T) -> Self
pub fn data<T: Into<Box<str>>>(self, val: T) -> Self
Base64-encoded encrypted JSON-serialized data with unique user’s payload, data hashes and secrets required for crate::types::EncryptedPassportElement decryption and authentication