StickerSet

Struct StickerSet 

pub struct StickerSet {
    pub name: Box<str>,
    pub title: Box<str>,
    pub sticker_type: Box<str>,
    pub stickers: Box<[Sticker]>,
    pub thumbnail: Option<PhotoSize>,
}
This object represents a sticker set.

Documentation

https://core.telegram.org/bots/api#stickerset

Fields

name: Box<str>

Sticker set name

title: Box<str>

Sticker set title

sticker_type: Box<str>

Type of stickers in the set, currently one of regular, mask, custom_emoji

stickers: Box<[Sticker]>

List of all set stickers

thumbnail: Option<PhotoSize>

Sticker set thumbnail in the .WEBP, .TGS, or .WEBM format

Implementations

Source

impl StickerSet

pub fn new<T0: Into<Box<str>>, T1: Into<Box<str>>, T2: Into<Box<str>>, T3Item: Into<Sticker>, T3: IntoIterator<Item = T3Item>>( name: T0, title: T1, sticker_type: T2, stickers: T3, ) -> Self

Creates a new StickerSet.

Arguments
  • name - Sticker set name
  • title - Sticker set title
  • sticker_type - Type of stickers in the set, currently one of regular, mask, custom_emoji
  • stickers - List of all set stickers
Notes

Use builder methods to set optional fields.

pub fn name<T: Into<Box<str>>>(self, val: T) -> Self

Sticker set name

pub fn title<T: Into<Box<str>>>(self, val: T) -> Self

Sticker set title

pub fn sticker_type<T: Into<Box<str>>>(self, val: T) -> Self

Type of stickers in the set, currently one of regular, mask, custom_emoji

pub fn stickers<T: Into<Box<[Sticker]>>>(self, val: T) -> Self

List of all set stickers

Notes

Adds multiple elements.

pub fn sticker<T: Into<Sticker>>(self, val: T) -> Self

List of all set stickers

Notes

Adds a single element.

pub fn thumbnail<T: Into<PhotoSize>>(self, val: T) -> Self

Sticker set thumbnail in the .WEBP, .TGS, or .WEBM format

pub fn thumbnail_option<T: Into<PhotoSize>>(self, val: Option<T>) -> Self

Sticker set thumbnail in the .WEBP, .TGS, or .WEBM format