pub struct Handler<Client> { /* private fields */ }Implementations
Sourceimpl<Client> Handler<Client>
impl<Client> Handler<Client>
Sourceimpl<Client> Handler<Client>
impl<Client> Handler<Client>
Sourcepub async fn check(
&mut self,
request: Request<Client>,
) -> Result<(bool, Request<Client>), (EventErrorKind, Request<Client>)>
pub async fn check( &mut self, request: Request<Client>, ) -> Result<(bool, Request<Client>), (EventErrorKind, Request<Client>)>
Check if the handler pass the filters. If the handler pass all them, it will be called.
Errors
If any filter returns error, it will be wrapped into FilterError
and returned together with the request