pub struct StickerSet {
pub name: Box<str>,
pub title: Box<str>,
pub sticker_type: Box<str>,
pub stickers: Box<[Sticker]>,
pub thumbnail: Option<PhotoSize>,
}Expand description
Fields
name: Box<str>Sticker set name
title: Box<str>Sticker set title
sticker_type: Box<str>Type of stickers in the set, currently one of regular, mask, custom_emoji
stickers: Box<[Sticker]>List of all set stickers
thumbnail: Option<PhotoSize>Sticker set thumbnail in the .WEBP, .TGS, or .WEBM format
Implementations
Sourceimpl StickerSet
impl StickerSet
Sourcepub fn new<T0: Into<Box<str>>, T1: Into<Box<str>>, T2: Into<Box<str>>, T3Item: Into<Sticker>, T3: IntoIterator<Item = T3Item>>(
name: T0,
title: T1,
sticker_type: T2,
stickers: T3,
) -> Self
pub fn new<T0: Into<Box<str>>, T1: Into<Box<str>>, T2: Into<Box<str>>, T3Item: Into<Sticker>, T3: IntoIterator<Item = T3Item>>( name: T0, title: T1, sticker_type: T2, stickers: T3, ) -> Self
Sourcepub fn sticker_type<T: Into<Box<str>>>(self, val: T) -> Self
pub fn sticker_type<T: Into<Box<str>>>(self, val: T) -> Self
Type of stickers in the set, currently one of regular, mask, custom_emoji
Sourcepub fn thumbnail<T: Into<PhotoSize>>(self, val: T) -> Self
pub fn thumbnail<T: Into<PhotoSize>>(self, val: T) -> Self
Sticker set thumbnail in the .WEBP, .TGS, or .WEBM format
Sourcepub fn thumbnail_option<T: Into<PhotoSize>>(self, val: Option<T>) -> Self
pub fn thumbnail_option<T: Into<PhotoSize>>(self, val: Option<T>) -> Self
Sticker set thumbnail in the .WEBP, .TGS, or .WEBM format